Struct mozjpeg_sys::jpeg_component_info [−][src]
#[repr(C)]pub struct jpeg_component_info { pub component_id: c_int, pub component_index: c_int, pub h_samp_factor: c_int, pub v_samp_factor: c_int, pub quant_tbl_no: c_int, pub dc_tbl_no: c_int, pub ac_tbl_no: c_int, pub width_in_blocks: JDIMENSION, pub height_in_blocks: JDIMENSION, pub quant_table: *mut JQUANT_TBL, // some fields omitted }
Fields
component_id: c_intidentifier for this component (0..255)
component_index: c_intits index in SOF or cinfo->comp_info[]
h_samp_factor: c_inthorizontal sampling factor (1..4)
v_samp_factor: c_intvertical sampling factor (1..4)
quant_tbl_no: c_intquantization table selector (0..3)
dc_tbl_no: c_intDC entropy table selector (0..3)
These values may vary between scans. For compression, they must be supplied by parameter setup; for decompression, they are read from the SOS marker. The decompressor output side may not use these variables.
ac_tbl_no: c_intAC entropy table selector (0..3)
width_in_blocks: JDIMENSIONheight_in_blocks: JDIMENSIONquant_table: *mut JQUANT_TBLTrait Implementations
impl Default for jpeg_component_info[src]
impl Default for jpeg_component_info[src]fn default() -> jpeg_component_info[src]