Please read libjpeg manual for description of functions in this crate.
Re-exports
pub use J_DCT_METHOD::JDCT_IFAST as JDCT_FASTEST;pub use J_DCT_METHOD::JDCT_ISLOW as JDCT_DEFAULT;pub use JINT_COMPRESS_PROFILE_VALUE::*;pub use J_BOOLEAN_PARAM::*;pub use J_COLOR_SPACE::*;pub use J_FLOAT_PARAM::*;pub use J_INT_PARAM::*;
Structs
- Routines that are to be used by both halves of the library are declared to receive a pointer to this structure. There are no actual instances of
jpeg_common_struct, only ofjpeg_compress_structandjpeg_decompress_struct. - Error handler object
- This is an opaque type. Don’t assume size or alignment of this struct.
- This is an opaque type. Don’t assume size or alignment of this struct.
Enums
- These 32-bit GUIDs and the corresponding
jpeg_*_get_*_param()jpeg_*_set_*_param()functions allow for extending the libjpeg API without breaking backward ABI compatibility. The actual parameters are stored in the opaquejpeg_comp_masterandjpeg_decomp_masterstructs.
Constants
- The basic DCT block is 8x8 samples
- DCTSIZE²
- lasts until done with image/datastream
- lasts until master record is destroyed
- Quantization tables are numbered 0..3
Functions
- This function provides application programmers with the ability to decompress only a portion of each row in the JPEG image. It must be called after jpeg_start_decompress() and before any calls to jpeg_read_scanlines() or jpeg_skip_scanlines(). If the output image is scaled, then xoffset and width are relative to the scaled image dimensions. xoffset and width are passed by reference because xoffset must fall on an iMCU boundary. If it doesn’t, then it will be moved left to the nearest iMCU boundary, and width will be increased accordingly.
- jpeg_
new_ ⚠colormap Deprecated - This function provides application programmers with the ability to skip over multiple rows in the JPEG image.
Type Aliases
- type for individual integer DCT coefficient
- one block of coefficients
- pointer to one row of coefficient blocks
- ptr to some rows (a 2-D sample array)
- a 3-D sample array: top index is color
- ptr to one image row of pixel samples.
- Equivalent to C’s
signed int(int) type. - Equivalent to C’s
signed long(long) type. - Equivalent to C’s
unsigned inttype. - Equivalent to C’s
unsigned longtype. - Equivalent to C’s
voidtype when used as a pointer.