Crate mozjpeg_sys [−] [src]
Please read libjpeg manual for description of functions in this crate.
Re-exports
pub use J_COLOR_SPACE::*; |
pub use J_BOOLEAN_PARAM::*; |
pub use J_FLOAT_PARAM::*; |
pub use J_INT_PARAM::*; |
pub use JINT_COMPRESS_PROFILE_VALUE::*; |
pub use J_DCT_METHOD::JDCT_ISLOW as JDCT_DEFAULT; |
pub use J_DCT_METHOD::JDCT_IFAST as JDCT_FASTEST; |
Structs
| JHUFF_TBL | |
| JQUANT_TBL | |
| jpeg_common_struct |
Routines that are to be used by both halves of the library are declared to receive a pointer to this structure. There are no actual instances of jpeg_common_struct, only of jpeg_compress_struct and jpeg_decompress_struct. |
| jpeg_component_info | |
| jpeg_compress_struct | |
| jpeg_decompress_struct | |
| jpeg_destination_mgr | |
| jpeg_error_mgr |
Error handler object |
| jpeg_marker_struct | |
| jpeg_memory_mgr | |
| jpeg_progress_mgr | |
| jpeg_scan_info | |
| jpeg_source_mgr | |
| msg_parm_union |
Enums
| FILE | |
| JINT_COMPRESS_PROFILE_VALUE | |
| J_BOOLEAN_PARAM |
These 32-bit GUIDs and the corresponding |
| J_COLOR_SPACE | |
| J_DCT_METHOD | |
| J_DITHER_MODE | |
| J_FLOAT_PARAM | |
| J_INT_PARAM | |
| c_void |
Equivalent to C's |
| jpeg_marker | |
| jvirt_barray_control | |
| jvirt_sarray_control |
Constants
| DCTSIZE |
The basic DCT block is 8x8 samples |
| DCTSIZE2 |
DCTSIZE² |
| JPEG_LIB_VERSION | |
| JPOOL_IMAGE |
lasts until done with image/datastream |
| JPOOL_PERMANENT |
lasts until master record is destroyed |
| NUM_QUANT_TBLS |
Quantization tables are numbered 0..3 |
Functions
Type Definitions
| DCTELEM |
type for individual integer DCT coefficient |
| JBLOCK |
one block of coefficients |
| JBLOCKARRAY | |
| JBLOCKROW |
pointer to one row of coefficient blocks |
| JCOEF | |
| JDIMENSION | |
| JSAMPARRAY |
ptr to some rows (a 2-D sample array) |
| JSAMPARRAY_MUT | |
| JSAMPIMAGE |
a 3-D sample array: top index is color |
| JSAMPIMAGE_MUT | |
| JSAMPLE | |
| JSAMPROW |
ptr to one image row of pixel samples. |
| JSAMPROW_MUT | |
| boolean | |
| c_int |
Equivalent to C's |
| c_long |
Equivalent to C's |
| c_uint |
Equivalent to C's |
| c_ulong |
Equivalent to C's |
| jpeg_marker_parser_method |