Enum mozjpeg_sys::J_COLOR_SPACE
source · #[repr(C)]pub enum J_COLOR_SPACE {
Show 17 variants
JCS_UNKNOWN,
JCS_GRAYSCALE,
JCS_RGB,
JCS_YCbCr,
JCS_CMYK,
JCS_YCCK,
JCS_EXT_RGB,
JCS_EXT_RGBX,
JCS_EXT_BGR,
JCS_EXT_BGRX,
JCS_EXT_XBGR,
JCS_EXT_XRGB,
JCS_EXT_RGBA,
JCS_EXT_BGRA,
JCS_EXT_ABGR,
JCS_EXT_ARGB,
JCS_RGB565,
}Variants
JCS_UNKNOWN
error/unspecified
JCS_GRAYSCALE
monochrome
JCS_RGB
red/green/blue as specified by the RGB_RED, RGB_GREEN, RGB_BLUE, and RGB_PIXELSIZE macros
JCS_YCbCr
Y/Cb/Cr (also known as YUV)
JCS_CMYK
C/M/Y/K
JCS_YCCK
Y/Cb/Cr/K
JCS_EXT_RGB
red/green/blue
JCS_EXT_RGBX
red/green/blue/x When out_color_space it set to JCS_EXT_RGBX, JCS_EXT_BGRX, JCS_EXT_XBGR, or JCS_EXT_XRGB during decompression, the X byte is undefined, and in order to ensure the best performance, libjpeg-turbo can set that byte to whatever value it wishes.
JCS_EXT_BGR
blue/green/red
JCS_EXT_BGRX
blue/green/red/x
JCS_EXT_XBGR
x/blue/green/red
JCS_EXT_XRGB
x/red/green/blue
JCS_EXT_RGBA
Use the following colorspace constants to ensure that the X byte is set to 0xFF, so that it can be interpreted as an opaque alpha channel.
red/green/blue/alpha
JCS_EXT_BGRA
blue/green/red/alpha
JCS_EXT_ABGR
alpha/blue/green/red
JCS_EXT_ARGB
alpha/red/green/blue
JCS_RGB565
5-bit red/6-bit green/5-bit blue