Enum mozjpeg_sys::J_COLOR_SPACE
[−]
[src]
#[repr(C)]pub enum J_COLOR_SPACE { JCS_UNKNOWN, JCS_GRAYSCALE, JCS_RGB, JCS_YCbCr, JCS_CMYK, JCS_YCCK, JCS_EXT_RGB, JCS_EXT_RGBX, JCS_EXT_BGR, JCS_EXT_BGRX, JCS_EXT_XBGR, JCS_EXT_XRGB, JCS_EXT_RGBA, JCS_EXT_BGRA, JCS_EXT_ABGR, JCS_EXT_ARGB, JCS_RGB565, }
Variants
JCS_UNKNOWNerror/unspecified
JCS_GRAYSCALEmonochrome
JCS_RGBred/green/blue as specified by the RGB_RED, RGB_GREEN, RGB_BLUE, and RGB_PIXELSIZE macros
JCS_YCbCrY/Cb/Cr (also known as YUV)
JCS_CMYKC/M/Y/K
JCS_YCCKY/Cb/Cr/K
JCS_EXT_RGBred/green/blue
JCS_EXT_RGBXred/green/blue/x When out_color_space it set to JCS_EXT_RGBX, JCS_EXT_BGRX, JCS_EXT_XBGR, or JCS_EXT_XRGB during decompression, the X byte is undefined, and in order to ensure the best performance, libjpeg-turbo can set that byte to whatever value it wishes.
JCS_EXT_BGRblue/green/red
JCS_EXT_BGRXblue/green/red/x
JCS_EXT_XBGRx/blue/green/red
JCS_EXT_XRGBx/red/green/blue
JCS_EXT_RGBAUse the following colorspace constants to ensure that the X byte is set to 0xFF, so that it can be interpreted as an opaque alpha channel.
red/green/blue/alpha
JCS_EXT_BGRAblue/green/red/alpha
JCS_EXT_ABGRalpha/blue/green/red
JCS_EXT_ARGBalpha/red/green/blue
JCS_RGB5655-bit red/6-bit green/5-bit blue